==> seedsui-react-5.5.1.tgz: package/es/DateRangePopover/DateRangePopover.js <==
var _excluded = ["visible", "onVisibleChange", "top", "left", "value", "ranges", "rangeErrMsg", "onChange", "maskAttribute", "caption", "startInputDateProps", "endInputDateProps"];

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { useState, forwardRef, Fragment } from 'react';
import Popover from './../Popover';
import locale from './../locale';
import DateRange from './DateRange';
import helper from './helper';
var range = 90; // 日期快捷选择弹窗

/**
 * @deprecated since version 5.2.8
 * 请使用DatePicker.Types
 */

var DateRangePopover = forwardRef(function (_ref, ref) {
  var _ref2;

  var _ref$visible = _ref.visible,
      visible = _ref$visible === void 0 ? false : _ref$visible,
      onVisibleChange = _ref.onVisibleChange,
      _ref$top = _ref.top,
      top = _ref$top === void 0 ? 88 : _ref$top,
      _ref$left = _ref.left,
      left = _ref$left === void 0 ? 10 : _ref$left,
      value = _ref.value,
      _ref$ranges = _ref.ranges,
      ranges = _ref$ranges === void 0 ? (_ref2 = {}, _ref2[locale('今天', 'datepopover_today')] = [new Date().format('YYYY-MM-DD'), new Date().format('YYYY-MM-DD')], _ref2[locale('昨天', 'datepopover_yesterday')] = [new Date().prevDate().format('YYYY-MM-DD'), new Date().prevDate().format('YYYY-MM-DD')], _ref2[locale('本月', 'datepopover_this_month')] = [new Date().firstMonthDate().format('YYYY-MM-DD'), new Date().format('YYYY-MM-DD')], _ref2[locale('上月', 'datepopover_last_month')] = [new Date().prevMonth().firstMonthDate().format('YYYY-MM-DD'), new Date().prevMonth().lastMonthDate().format('YYYY-MM-DD')], _ref2[locale('最近7天', 'datepopover_last_days', ['7'])] = [new Date().prevDate(7).format('YYYY-MM-DD'), new Date().format('YYYY-MM-DD')], _ref2[locale('最近30天', 'datepopover_last_days', ['30'])] = [new Date().prevDate(30).format('YYYY-MM-DD'), new Date().format('YYYY-MM-DD')], _ref2[locale('自定义时间', 'datepopover_custom_date')] = 90, _ref2) : _ref$ranges,
      rangeErrMsg = _ref.rangeErrMsg,
      onChange = _ref.onChange,
      maskAttribute = _ref.maskAttribute,
      _ref$caption = _ref.caption,
      caption = _ref$caption === void 0 ? locale('自定义时间', 'datepopover_custom_date') : _ref$caption,
      _ref$startInputDatePr = _ref.startInputDateProps,
      startInputDateProps = _ref$startInputDatePr === void 0 ? {} : _ref$startInputDatePr,
      _ref$endInputDateProp = _ref.endInputDateProps,
      endInputDateProps = _ref$endInputDateProp === void 0 ? {} : _ref$endInputDateProp,
      others = _objectWithoutPropertiesLoose(_ref, _excluded);

  var startDate = '';
  var endDate = '';

  if (Array.isArray(value) && value.length === 2) {
    startDate = value[0] || '';
    endDate = value[1] || '';
  } // 自定义日期数据


  var _useState = useState(false),
      rangeVisible = _useState[0],
      setRangeVisible = _useState[1]; // 修改日期


  function handleChangeDate(e, startDate, endDate) {
    if (onChange) {
      onChange(e, [startDate, endDate], helper.getDateName(startDate, endDate));
    }

    if (onVisibleChange) onVisibleChange(false);
  } // 显示自定义弹框


  function showCustomDialog(currentRange) {
    // 设置区间不能超过?天
    range = currentRange;
    setRangeVisible(true);
    if (onVisibleChange) onVisibleChange();
  } // 修改自定义日期


  function handleChangeCustom(e, values) {
    setRangeVisible(false);

    if (onChange) {
      onChange(e, values, helper.getDateName(values[0], values[1]));
    }
  }

  if (!ranges || typeof ranges !== 'object') {
    return null;
  }

  return /*#__PURE__*/React.createElement(Fragment, null, /*#__PURE__*/React.createElement(Popover, _extends({
    ref: ref,
    show: visible
  }, others, {
    className: "datepopover " + (others.className || 'top-left'),
    style: Object.assign({
      left: left + "px",
      top: top + "px"
    }, others.style || {}),
    maskAttribute: Object.assign({}, {
      onClick: function onClick() {
        if (onVisibleChange) onVisibleChange(false);
      }
    }, maskAttribute || {})
  }), Object.entries(ranges).map(function (item) {
    var _React$createElement;

    var key = item[0];
    var range = item[1];

    if (typeof range === 'number') {
      return /*#__PURE__*/React.createElement("div", {
        className: "datepopover-option",
        key: key,
        onClick: function onClick() {
          return showCustomDialog(range);
        }
      }, locale('自定义时间', 'datepopover_custom_date'));
    }

    return /*#__PURE__*/React.createElement("div", (_React$createElement = {
      className: "border-b",
      key: key
    }, _React$createElement["className"] = "datepopover-option", _React$createElement.onClick = function onClick(e) {
      return handleChangeDate(e, range[0], range[1]);
    }, _React$createElement), key);
  })), /*#__PURE__*/React.createElement(DateRange, {
    caption: caption,
    visible: rangeVisible,
    start: startDate,
    end: endDate,
    startInputDateProps: startInputDateProps,
    endInputDateProps: endInputDateProps // 确定前校验
    ,
    onSubmitBefore: function onSubmitBefore(e, values) {
      if (!helper.isRange(values[0], values[1], range, rangeErrMsg)) {
        return false;
      }

      return true;
    },
    onChange: handleChangeCustom,
    onVisibleChange: setRangeVisible
  }));
});
export default DateRangePopover;

==> seedsui-react-5.5.8.tgz: package/es/DateRangePopover/DateRangePopover.js <==
var _excluded = ["visible", "onVisibleChange", "top", "left", "value", "ranges", "rangeErrMsg", "onChange", "maskAttribute", "caption", "startInputDateProps", "endInputDateProps"];

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { useState, forwardRef, Fragment } from 'react';
import Popover from './../Popover';
import locale from './../locale';
import DateRange from './DateRange';
import helper from './helper';
var range = 90; // 日期快捷选择弹窗

/**
 * @deprecated since version 5.2.8
 * 请使用DatePicker.Types
 */

var DateRangePopover = forwardRef(function (_ref, ref) {
  var _ref2;

  var _ref$visible = _ref.visible,
      visible = _ref$visible === void 0 ? false : _ref$visible,
      onVisibleChange = _ref.onVisibleChange,
      _ref$top = _ref.top,
      top = _ref$top === void 0 ? 88 : _ref$top,
      _ref$left = _ref.left,
      left = _ref$left === void 0 ? 10 : _ref$left,
      value = _ref.value,
      _ref$ranges = _ref.ranges,
      ranges = _ref$ranges === void 0 ? (_ref2 = {}, _ref2[locale('今天', 'datepopover_today')] = [new Date().format('YYYY-MM-DD'), new Date().format('YYYY-MM-DD')], _ref2[locale('昨天', 'datepopover_yesterday')] = [new Date().prevDate().format('YYYY-MM-DD'), new Date().prevDate().format('YYYY-MM-DD')], _ref2[locale('本月', 'datepopover_this_month')] = [new Date().firstMonthDate().format('YYYY-MM-DD'), new Date().format('YYYY-MM-DD')], _ref2[locale('上月', 'datepopover_last_month')] = [new Date().prevMonth().firstMonthDate().format('YYYY-MM-DD'), new Date().prevMonth().lastMonthDate().format('YYYY-MM-DD')], _ref2[locale('最近7天', 'datepopover_last_days', ['7'])] = [new Date().prevDate(7).format('YYYY-MM-DD'), new Date().format('YYYY-MM-DD')], _ref2[locale('最近30天', 'datepopover_last_days', ['30'])] = [new Date().prevDate(30).format('YYYY-MM-DD'), new Date().format('YYYY-MM-DD')], _ref2[locale('自定义时间', 'datepopover_custom_date')] = 90, _ref2) : _ref$ranges,
      rangeErrMsg = _ref.rangeErrMsg,
      onChange = _ref.onChange,
      maskAttribute = _ref.maskAttribute,
      _ref$caption = _ref.caption,
      caption = _ref$caption === void 0 ? locale('自定义时间', 'datepopover_custom_date') : _ref$caption,
      _ref$startInputDatePr = _ref.startInputDateProps,
      startInputDateProps = _ref$startInputDatePr === void 0 ? {} : _ref$startInputDatePr,
      _ref$endInputDateProp = _ref.endInputDateProps,
      endInputDateProps = _ref$endInputDateProp === void 0 ? {} : _ref$endInputDateProp,
      others = _objectWithoutPropertiesLoose(_ref, _excluded);

  var startDate = '';
  var endDate = '';

  if (Array.isArray(value) && value.length === 2) {
    startDate = value[0] || '';
    endDate = value[1] || '';
  } // 自定义日期数据


  var _useState = useState(false),
      rangeVisible = _useState[0],
      setRangeVisible = _useState[1]; // 修改日期


  function handleChangeDate(e, startDate, endDate) {
    if (onChange) {
      onChange(e, [startDate, endDate], helper.getDateName(startDate, endDate));
    }

    if (onVisibleChange) onVisibleChange(false);
  } // 显示自定义弹框


  function showCustomDialog(currentRange) {
    // 设置区间不能超过?天
    range = currentRange;
    setRangeVisible(true);
    if (onVisibleChange) onVisibleChange();
  } // 修改自定义日期


  function handleChangeCustom(e, values) {
    setRangeVisible(false);

    if (onChange) {
      onChange(e, values, helper.getDateName(values[0], values[1]));
    }
  }

  if (!ranges || typeof ranges !== 'object') {
    return null;
  }

  return /*#__PURE__*/React.createElement(Fragment, null, /*#__PURE__*/React.createElement(Popover, _extends({
    ref: ref,
    show: visible
  }, others, {
    className: "datepopover " + (others.className || 'top-left'),
    style: Object.assign({
      left: left + "px",
      top: top + "px"
    }, others.style || {}),
    maskAttribute: Object.assign({}, {
      onClick: function onClick() {
        if (onVisibleChange) onVisibleChange(false);
      }
    }, maskAttribute || {})
  }), Object.entries(ranges).map(function (item) {
    var key = item[0];
    var range = item[1];

    if (typeof range === 'number') {
      return /*#__PURE__*/React.createElement("div", {
        className: "datepopover-option",
        key: key,
        onClick: function onClick() {
          return showCustomDialog(range);
        }
      }, locale('自定义时间', 'datepopover_custom_date'));
    }

    return /*#__PURE__*/React.createElement("div", {
      key: key,
      className: "datepopover-option",
      onClick: function onClick(e) {
        return handleChangeDate(e, range[0], range[1]);
      }
    }, key);
  })), /*#__PURE__*/React.createElement(DateRange, {
    caption: caption,
    visible: rangeVisible,
    start: startDate,
    end: endDate,
    startInputDateProps: startInputDateProps,
    endInputDateProps: endInputDateProps // 确定前校验
    ,
    onSubmitBefore: function onSubmitBefore(e, values) {
      if (!helper.isRange(values[0], values[1], range, rangeErrMsg)) {
        return false;
      }

      return true;
    },
    onChange: handleChangeCustom,
    onVisibleChange: setRangeVisible
  }));
});
export default DateRangePopover;
